<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Notifications</source>
        <translation>Notificações</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Som</translation>
    </message>
    <message>
        <source>Sound player</source>
        <translation>Reprodutor de audio</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Reprodutor</translation>
    </message>
</context>
</TS>